==> jc-tke-service-1.1.329-sources.jar: com/xforceplus/jctke/controller/FlowreplaylogSotkq5hhxap8nkusgg3jtpController.java <==
package com.xforceplus.jctke.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jctke.entity.FlowreplaylogSotkq5hhxap8nkusgg3jtp;
import com.xforceplus.jctke.service.IFlowreplaylogSotkq5hhxap8nkusgg3jtpService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-11-05
 */
@RestController
public class FlowreplaylogSotkq5hhxap8nkusgg3jtpController {

  @Autowired
  private IFlowreplaylogSotkq5hhxap8nkusgg3jtpService flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return
   */
  @GetMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps" )
  public XfR getFlowreplaylogSotkq5hhxap8nkusgg3jtps(XfPage page, FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp) {
    return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.page(page, Wrappers.query(flowreplaylogSotkq5hhxap8nkusgg3jtp)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return XfR
   */
  @PostMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps")
  public XfR save(@RequestBody FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp) {
     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.save(flowreplaylogSotkq5hhxap8nkusgg3jtp));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return XfR
   */
  @PutMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR putUpdate(@RequestBody FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp,@PathVariable Long id) {
      flowreplaylogSotkq5hhxap8nkusgg3jtp.setId(id);
      return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.updateById(flowreplaylogSotkq5hhxap8nkusgg3jtp));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return XfR
   */
  @PatchMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR patchUpdate(@RequestBody FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp,@PathVariable Long id) {
      FlowreplaylogSotkq5hhxap8nkusgg3jtp upflowreplaylogSotkq5hhxap8nkusgg3jtp = flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.getById(id);
      if(upflowreplaylogSotkq5hhxap8nkusgg3jtp != null){
        upflowreplaylogSotkq5hhxap8nkusgg3jtp = ObjectCopyUtils.copyProperties(flowreplaylogSotkq5hhxap8nkusgg3jtp,upflowreplaylogSotkq5hhxap8nkusgg3jtp,true);
      }
      return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.updateById(upflowreplaylogSotkq5hhxap8nkusgg3jtp));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.removeById(id));
  }

  @PostMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "flowreplaylog_sotkq5hhxap8nkusgg3jtp");
     params.put("request", condition);

     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.querys(params));
  }

}

==> jc-tke-service-1.1.385-sources.jar: com/xforceplus/jctke/controller/FlowreplaylogSotkq5hhxap8nkusgg3jtpController.java <==
package com.xforceplus.jctke.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.jctke.entity.FlowreplaylogSotkq5hhxap8nkusgg3jtp;
import com.xforceplus.jctke.service.IFlowreplaylogSotkq5hhxap8nkusgg3jtpService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2022-12-01
 */
@RestController
public class FlowreplaylogSotkq5hhxap8nkusgg3jtpController {

  @Autowired
  private IFlowreplaylogSotkq5hhxap8nkusgg3jtpService flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return
   */
  @GetMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps" )
  public XfR getFlowreplaylogSotkq5hhxap8nkusgg3jtps(XfPage page, FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp) {
    return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.page(page, Wrappers.query(flowreplaylogSotkq5hhxap8nkusgg3jtp)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return XfR
   */
  @PostMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps")
  public XfR save(@RequestBody FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp) {
     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.save(flowreplaylogSotkq5hhxap8nkusgg3jtp));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return XfR
   */
  @PutMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR putUpdate(@RequestBody FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp,@PathVariable Long id) {
      flowreplaylogSotkq5hhxap8nkusgg3jtp.setId(id);
      return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.updateById(flowreplaylogSotkq5hhxap8nkusgg3jtp));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param flowreplaylogSotkq5hhxap8nkusgg3jtp ${table.comment}
   * @return XfR
   */
  @PatchMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR patchUpdate(@RequestBody FlowreplaylogSotkq5hhxap8nkusgg3jtp flowreplaylogSotkq5hhxap8nkusgg3jtp,@PathVariable Long id) {
      FlowreplaylogSotkq5hhxap8nkusgg3jtp upflowreplaylogSotkq5hhxap8nkusgg3jtp = flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.getById(id);
      if(upflowreplaylogSotkq5hhxap8nkusgg3jtp != null){
        upflowreplaylogSotkq5hhxap8nkusgg3jtp = ObjectCopyUtils.copyProperties(flowreplaylogSotkq5hhxap8nkusgg3jtp,upflowreplaylogSotkq5hhxap8nkusgg3jtp,true);
      }
      return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.updateById(upflowreplaylogSotkq5hhxap8nkusgg3jtp));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.removeById(id));
  }

  @PostMapping("/flowreplaylogsotkq5hhxap8nkusgg3jtps/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "flowreplaylog_sotkq5hhxap8nkusgg3jtp");
     params.put("request", condition);

     return XfR.ok(flowreplaylogSotkq5hhxap8nkusgg3jtpServiceImpl.querys(params));
  }

}
